@@ -57,6 +57,7 @@
 #include "Logger.h"
 #include "Misc.h"
 #include "ParametersCache.h"
+#include "Settings.h"
 #include "Updater.h"
 #include "Utils.h"
 #include "Widgets/VisibleTagSelector.h"
@@ -207,7 +208,7 @@ MainWindow::MainWindow(QWidget * parent) : QMainWindow(parent), ui(new Ui::MainW
   }
 
   QPalette p = QGuiApplication::palette();
-  DialogSettings::UnselectedFilterTextColor = p.color(QPalette::Disabled, QPalette::WindowText);
+  Settings::UnselectedFilterTextColor = p.color(QPalette::Disabled, QPalette::WindowText);
 
   _filtersPresenter = new FiltersPresenter(this);
   _filtersPresenter->setFiltersView(ui->filtersView);
@@ -309,8 +310,8 @@ void MainWindow::setDarkTheme()
   qApp->setPalette(p);
 
   p = ui->cbInternetUpdate->palette();
-  p.setColor(QPalette::Text, DialogSettings::CheckBoxTextColor);
-  p.setColor(QPalette::Base, DialogSettings::CheckBoxBaseColor);
+  p.setColor(QPalette::Text, Settings::CheckBoxTextColor);
+  p.setColor(QPalette::Base, Settings::CheckBoxBaseColor);
   ui->cbInternetUpdate->setPalette(p);
   ui->cbPreview->setPalette(p);
 
@@ -331,7 +332,7 @@ void MainWindow::setDarkTheme()
   qApp->setStyleSheet(css);
   ui->inOutSelector->setDarkTheme();
   ui->vSplitterLine->setStyleSheet("QFrame{ border-top: 0px none #a0a0a0; border-bottom: 1px solid rgb(160,160,160);}");
-  DialogSettings::UnselectedFilterTextColor = DialogSettings::UnselectedFilterTextColor.darker(150);
+  Settings::UnselectedFilterTextColor = Settings::UnselectedFilterTextColor.darker(150);
 }
 #endif
 
@@ -472,11 +473,12 @@ void MainWindow::retrieveFilterAndParametersFromPluginParameters(QString & hash,
 
 void MainWindow::onStartupFiltersUpdateFinished(int status)
 {
-  QObject::disconnect(Updater::getInstance(), SIGNAL(updateIsDone(int)), this, SLOT(onStartupFiltersUpdateFinished(int)));
+  bool ok = QObject::disconnect(Updater::getInstance(), &Updater::updateIsDone, this, &MainWindow::onStartupFiltersUpdateFinished);
+  Q_ASSERT_X(ok, __PRETTY_FUNCTION__, "Cannot disconnect Updater::updateIsDone from MainWindow::onStartupFiltersUpdateFinished");
 
   ui->progressInfoWidget->stopAnimationAndHide();
   if (status == (int)Updater::UpdateStatus::SomeFailed) {
-    if (DialogSettings::notifyFailedStartupUpdate()) {
+    if (Settings::notifyFailedStartupUpdate()) {
       showMessage(tr("Filters update could not be achieved"), 3000);
     }
   } else if (status == (int)Updater::UpdateStatus::Successful) {
@@ -645,7 +647,7 @@ void MainWindow::makeConnections()
   connect(ui->zoomLevelSelector, SIGNAL(zoomReset()), this, SLOT(onPreviewZoomReset()));
 
   connect(ui->tbAddFave, SIGNAL(clicked(bool)), this, SLOT(onAddFave()));
-  connect(_filtersPresenter, SIGNAL(faveAdditionRequested(QString)), this, SLOT(onAddFave()));
+  connect(_filtersPresenter, &FiltersPresenter::faveAdditionRequested, this, &MainWindow::onAddFave);
   connect(ui->tbRemoveFave, &QToolButton::clicked, this, &MainWindow::onRemoveFave);
   connect(ui->tbRenameFave, &QToolButton::clicked, this, &MainWindow::onRenameFave);
   connect(ui->inOutSelector, SIGNAL(inputModeChanged(InputMode)), this, SLOT(onInputModeChanged(InputMode)));
@@ -691,17 +693,19 @@ void MainWindow::onPreviewUpdateRequested(bool synchronous)
   context.requestType = synchronous ? GmicProcessor::FilterContext::RequestType::SynchronousPreview : GmicProcessor::FilterContext::RequestType::Preview;
   GmicProcessor::FilterContext::VisibleRect & rect = context.visibleRect;
   ui->previewWidget->normalizedVisibleRect(rect.x, rect.y, rect.w, rect.h);
+
   context.inputOutputState = ui->inOutSelector->state();
-  context.outputMessageMode = DialogSettings::outputMessageMode();
+  context.outputMessageMode = Settings::outputMessageMode();
   ui->previewWidget->getPositionStringCorrection(context.positionStringCorrection.xFactor, context.positionStringCorrection.yFactor);
   context.zoomFactor = ui->previewWidget->currentZoomFactor();
-  context.previewWidth = ui->previewWidget->width();
-  context.previewHeight = ui->previewWidget->height();
-  context.previewTimeout = DialogSettings::previewTimeout();
+  context.previewWindowWidth = ui->previewWidget->width();
+  context.previewWindowHeight = ui->previewWidget->height();
+  context.previewTimeout = Settings::previewTimeout();
   // context.filterName = currentFilter.plainTextName; // Unused in this context
   // context.filterHash = currentFilter.hash; // Unused in this context
   context.filterCommand = currentFilter.previewCommand;
   context.filterArguments = ui->filterParams->valueString();
+  context.previewFromFullImage = currentFilter.previewFromFullImage;
   _processor.setContext(context);
   _processor.execute();
 
@@ -801,13 +805,14 @@ void MainWindow::processImage()
   GmicProcessor::FilterContext::VisibleRect & rect = context.visibleRect;
   rect.x = rect.y = rect.w = rect.h = -1;
   context.inputOutputState = ui->inOutSelector->state();
-  context.outputMessageMode = DialogSettings::outputMessageMode();
+  context.outputMessageMode = Settings::outputMessageMode();
   context.filterName = currentFilter.plainTextName;
   context.filterFullPath = currentFilter.fullPath;
   context.filterHash = currentFilter.hash;
   context.filterCommand = currentFilter.command;
   ui->filterParams->updateValueString(false); // Required to get up-to-date values of text parameters
   context.filterArguments = ui->filterParams->valueString();
+  context.previewFromFullImage = false;
   _processor.setGmicStatusQuotedParameters(ui->filterParams->quotedParameters());
   ui->filterParams->clearButtonParameters();
   _processor.setContext(context);
@@ -834,7 +839,7 @@ void MainWindow::setZoomConstraint()
 {
   const FiltersPresenter::Filter & currentFilter = _filtersPresenter->currentFilter();
   ZoomConstraint constraint;
-  if (currentFilter.hash.isEmpty() || currentFilter.isAccurateIfZoomed || DialogSettings::previewZoomAlwaysEnabled() || (currentFilter.previewFactor == PreviewFactorAny)) {
+  if (currentFilter.hash.isEmpty() || currentFilter.isAccurateIfZoomed || Settings::previewZoomAlwaysEnabled() || (currentFilter.previewFactor == PreviewFactorAny)) {
     constraint = ZoomConstraint::Any;
   } else if (currentFilter.previewFactor == PreviewFactorActualSize) {
     constraint = ZoomConstraint::OneOrMore;
@@ -1003,7 +1008,7 @@ void MainWindow::saveSettings()
 
   // Save all settings
 
-  DialogSettings::saveSettings(settings);
+  Settings::save(settings);
   settings.setValue("LastExecution/gmic_version", gmic_version);
   _processor.saveSettings(settings);
   settings.setValue("SelectedFilter", _filtersPresenter->currentFilter().hash);
@@ -1044,11 +1049,11 @@ void MainWindow::loadSettings()
     setPreviewPosition(PreviewPosition::Left);
   }
 #ifndef _GMIC_QT_DISABLE_THEMING_
-  if (DialogSettings::darkThemeEnabled()) {
+  if (Settings::darkThemeEnabled()) {
     setDarkTheme();
   }
 #endif
-  if (!DialogSettings::logosAreVisible()) {
+  if (!Settings::visibleLogos()) {
     ui->logosLabel->hide();
   }
 
@@ -1266,8 +1271,8 @@ void MainWindow::showEvent(QShowEvent * event)
     Logger::clear();
   }
   QObject::connect(Updater::getInstance(), &Updater::updateIsDone, this, &MainWindow::onStartupFiltersUpdateFinished);
-  Logger::setMode(DialogSettings::outputMessageMode());
-  Updater::setOutputMessageMode(DialogSettings::outputMessageMode());
+  Logger::setMode(Settings::outputMessageMode());
+  Updater::setOutputMessageMode(Settings::outputMessageMode());
   int ageLimit;
   {
     GMIC_SETTINGS(settings);
@@ -1297,10 +1302,10 @@ bool MainWindow::askUserForGTKFavesImport()
   messageBox.setDefaultButton(QMessageBox::Yes);
   QCheckBox * cb = new QCheckBox(tr("Don't ask again"));
 #ifndef _GMIC_QT_DISABLE_THEMING_
-  if (DialogSettings::darkThemeEnabled()) {
+  if (Settings::darkThemeEnabled()) {
     QPalette p = cb->palette();
-    p.setColor(QPalette::Text, DialogSettings::CheckBoxTextColor);
-    p.setColor(QPalette::Base, DialogSettings::CheckBoxBaseColor);
+    p.setColor(QPalette::Text, Settings::CheckBoxTextColor);
+    p.setColor(QPalette::Base, Settings::CheckBoxBaseColor);
     cb->setPalette(p);
   }
 #endif
@@ -1362,8 +1367,8 @@ void MainWindow::onSettingsClicked()
 
   DialogSettings dialog(this);
   dialog.exec();
-  bool previewPositionChanged = (_previewPosition != DialogSettings::previewPosition());
-  setPreviewPosition(DialogSettings::previewPosition());
+  bool previewPositionChanged = (_previewPosition != Settings::previewPosition());
+  setPreviewPosition(Settings::previewPosition());
   if (previewPositionChanged) {
     splitterSizes.clear();
     if (_previewPosition == PreviewPosition::Left) {
@@ -1378,7 +1383,7 @@ void MainWindow::onSettingsClicked()
     ui->splitter->setSizes(splitterSizes);
   }
   bool shouldUpdatePreview = false;
-  if (DialogSettings::logosAreVisible()) {
+  if (Settings::visibleLogos()) {
     if (!ui->logosLabel->isVisible()) {
       shouldUpdatePreview = true;
       ui->logosLabel->show();
@@ -1394,7 +1399,7 @@ void MainWindow::onSettingsClicked()
   }
   // Manage zoom constraints
   setZoomConstraint();
-  if (!DialogSettings::previewZoomAlwaysEnabled()) {
+  if (!Settings::previewZoomAlwaysEnabled()) {
     const FiltersPresenter::Filter & filter = _filtersPresenter->currentFilter();
     if (((ui->previewWidget->zoomConstraint() == ZoomConstraint::Fixed) && (ui->previewWidget->defaultZoomFactor() != ui->previewWidget->currentZoomFactor())) ||
         ((ui->previewWidget->zoomConstraint() == ZoomConstraint::OneOrMore) && (ui->previewWidget->currentZoomFactor() < 1.0))) {
